.. Simple Machine Learning Tool Kit documentation master file, created by
   sphinx-quickstart on Mon Oct 25 06:16:25 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Simple Machine Learning Tool Kit's documentation!
============================================================

This package contains the classes to manage data preprocessing, testing and reporting.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   api
   usage
   development

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
